# McFine: A tool for hyperfine spectral line fitting

[![](https://img.shields.io/pypi/v/mcfine.svg?label=PyPI&style=flat-square)](https://pypi.org/pypi/mcfine/)
[![](https://img.shields.io/pypi/pyversions/mcfine.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/pypi/mcfine/)
[![Actions](https://img.shields.io/github/actions/workflow/status/thomaswilliamsastro/mcfine/test_build.yml?branch=main)](https://github.com/thomaswilliamsastro/mcfine/actions)
[![Docs](https://readthedocs.org/projects/mcfine/badge/?version=latest&style=flat-square)](https://mcfine.readthedocs.io/en/latest/)
[![License](https://img.shields.io/badge/license-GNUv3-blue.svg?label=License&style=flat-square)](LICENSE)

A python package for complex, multi-component hyperfine spectra fitting in astronomical data.

## Installation

* McFine is pip installable

```shell
$ pip install mcfine
```

Or if you want to also use the RT capabilities:

```shell
$ pip install mcfine[rt]
```

## Documentation

Full documentation is available at https://mcfine.readthedocs.io, along with some examples and
demonstrations of features.

A more philosophical introduction to McFine is presented in Williams & Watkins (in prep.), along with some tests of how
well the code performs in synthetic tests and on real life space data.

## Problems?

Feel free to email me, thomas.g.williams94 (at) gmail.com
